@@ -6,28 +6,38 @@ import logging
 from styler_rest_framework.schemas.error import (
     HTTP400Error,
     HTTP401Error,
+    HTTP402Error,
     HTTP403Error,
     HTTP404Error,
-    HTTP409Error
+    HTTP409Error,
 )
 from fastapi import HTTPException
 from styler_rest_framework.exceptions.business import (
     PermissionDeniedError,
     ResourceNotFoundError,
     ValidationError,
-    ConflictError
+    ConflictError,
+)
+from styler_rest_framework.exceptions.services import (
+    AuthenticationError,
+    AuthorizationError,
+    InvalidDataError,
+    NotFoundError,
+    PaymentRequiredError,
 )
 
 
 def standard(*codes) -> Dict:
     """ Generate the default configuration for error codes
     """
-    codes = codes or (400, 401, 403, 404, 409)
+    codes = codes or (400, 401, 402, 403, 404, 409)
     responses = {}
     if 400 in codes:
         responses[400] = {'model': HTTP400Error}
     if 401 in codes:
         responses[401] = {'model': HTTP401Error}
+    if 402 in codes:
+        responses[402] = {'model': HTTP402Error}
     if 403 in codes:
         responses[403] = {'model': HTTP403Error}
     if 404 in codes:
@@ -37,10 +47,22 @@ def standard(*codes) -> Dict:
     return responses
 
 
-def bad_request(errors: Dict[str, str]):
+def bad_request(errors: Dict[str, str], code='validation_error'):
     """ Return HTTP 400 error
     """
-    raise HTTPException(status_code=400, detail=errors)
+    raise HTTPException(status_code=400, detail={
+        'code': code,
+        'reason': errors,
+    })
+
+
+def payment_required(code: str, reason: str):
+    """ Return HTTP 402 error
+    """
+    raise HTTPException(status_code=402, detail={
+        'code': code,
+        'reason': reason,
+    })
 
 
 def forbidden(msg=None):
@@ -91,3 +113,21 @@ def handle_business_errors(exception: Exception) -> None:
         conflict(exception.msg)
     else:
         internal_server_error(exception)
+
+
+def handle_service_errors(ex):
+    """ Default method for handling service related errors
+    """
+    if isinstance(ex, InvalidDataError):
+        bad_request(ex.json_body().get('reason'))
+    elif isinstance(ex, AuthenticationError):
+        unauthorized()
+    elif isinstance(ex, PaymentRequiredError):
+        body = ex.json_body()
+        payment_required(body.get('code'), body.get('reason'))
+    elif isinstance(ex, AuthorizationError):
+        forbidden()
+    elif isinstance(ex, NotFoundError):
+        not_found()
+    else:
+        internal_server_error(exception=ex)
